arrc.models.embeddings.simple\_cnn
==================================

.. automodule:: arrc.models.embeddings.simple_cnn

   
   .. rubric:: Functions

   .. autosummary::
   
      build_cnn_model
   